@@ -1,6 +1,6 @@
-import Image
-import ImageDraw
-import ImageFont
+from PIL import Image
+from PIL import ImageDraw
+from PIL import ImageFont
 
 # Change these values to match your needs
 cert_file = '/home/apyb/certificado2009.png'
